#
# spec file for package vkquake
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017 Luke Jones <luke.nukem.jones@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vkquake
Version:        1.32.1
Release:        1.2
Summary:        Quake 1 port using Vulkan instead of OpenGL for rendering
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/Novum/vkQuake
Source:         https://github.com/Novum/vkQuake/archive/refs/tags/%{version}.tar.gz#/vkQuake-%{version}.tar.gz
Source99:       %{name}.changes
Source100:      appdata.xml
Source101:      %{name}.desktop
BuildRequires:  cmake
BuildRequires:  glslang-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  spirv-tools
# from quakedef.h "Vulkan is too old" preprocessor check
BuildRequires:  vulkan-devel >= 1.2.162
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(libmikmod)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc11
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++
%endif

%description
vkQuake is a Quake 1 port using Vulkan instead of OpenGL for rendering. It is based on the popular QuakeSpasm port and runs all mods compatible with it like Arcane Dimensions or In The Shadows.
Game data must be placed in ~/.vkquake/id1 .

%prep
%autosetup -n vkQuake-%{version}

# Drop pre-compiled Windows stuff
rm Windows -fr

# Fix usage of __DATE__ and __TIME__ macros to prevent build in excess
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" Quake/host.c

%build
%meson -Ddo_userdirs=enabled
%meson_build

%install
install -Dm755 %{_vpath_builddir}/vkquake %{buildroot}%{_bindir}/%{name}
install -D -p -m 644 Misc/vkQuake_512.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -D -p -m 644 %{SOURCE100} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -D -p -m 644 %{SOURCE101} %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license LICENSE.txt
%doc readme.md Misc/fitzquake080.txt Misc/fitzquake080sdl.txt Misc/fitzquake085.txt
%{_bindir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Wed Mar  5 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.32.1
  * Fixes:
  - #772: Performance regression when host_maxfps > 72 visible on
    especially large levels (you know what they are)
  - #764: Align modern hud closer to the remaster and render keys for
    hipnotic as well
  - #779: Erroneous assertion triggered
  * Improvements:
  - Boost fps on especially large levels by enabling sv_fastpushmove 1
    by default. Can be disabled (0) at any time if something goes wrong
  - #765: Standalone MD5 support. Mods can now use MD5 in QuakeC explicitly
    as *.md5mesh the same way *.mdl was used before. The 2 types of models
    can be mixed in the same progs.dat of course
  - Code cleanups
  - Library updates
* Sun Jan 12 2025 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.32.0
  * Fixes:
  - #755: A VERY important, long-standing bug in the GPU Memory
    allocator fixed by @Novum, that could create all kinds of
    graphics corruption and even random crashes
  - #747: Fix Vulkan crashes when taking screenshots
  - #752, #761: MD5 models now manage 32bit textures correctly
    for both skins and fullbrights
  * Improvements:
  - #753: Add external WAD, WAD3, and Half-life format support.
    This great addition was brought by @Toodles2You, many thanks.
    This feature was also added to Quakespasm !
  - Removed most of the size limits for models, the one remaining
    is a 32K limit on model vertices. (from Ironwail)
  - Code cleanups
  - Library updates
* Fri Nov  8 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.31.3
  * Improvements:
  - Library updates : vkQuake is now using mpg123 by default instead
    of mad for mp3 support
  * Fixes:
  - #740: Fix broken saves in Mjolnir
  - #718: Fix MD5 models to support multi-meshes. Quake Remaster models
    were fine because mono-mesh, but other addons exist bringing multi-mesh
    MD5 models
  - Some smaller fixes here and there.
* Wed Oct  2 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.31.2
  * Improvements
  - Added proper nomonsters 1 option : Don't spawn monsters when starting a map
  - Add ability to bind function keys (F1-F12) in Key Bindings menu
  - Key Bindings now able to remap the usual Quake shortcuts bounded to
    function keys before
  - Allow any supported music type to play
  - Library updates
  - Code cleanups
  * Fixes
  - #734: Fix a potentially game-breaking bug, manifesting itself as
    frozen entities, or even game events not triggered at all
  - Vulkan fixes by @Novum
  - Remove "CDAudio disabled at compile time" message
  - Some smaller fixes here and there
* Fri Aug  2 2024 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.31.1.1
  * Improvements
  - Removed option Game > Load last save = fast, replaced by the addition
    of Game > Fast loading = on/off applicable to all loading actions:
    With Fast loading = on, loading the same level over and over become
    almost instantaneous, even for monster levels, like The Immortal Lock
  - Library updates
  - Code cleanups
  * Fixes
  - Various Linux build fixes (makefile)
  - Moving Elevators hurting player and monsters, with fixes by @andrei-drexler
    (sv_gamefix_elevators CVAR) and others
  - Remove Sky_ClipPoly: MAX_CLIP_VERTS hardcoded limit
  - Sound resample compute can overflow with very big sounds
  - Host_error: ed_alloc: no free edicts due to edicts "leak", showing up on big levels in particular
* Sat Jun 22 2024 Michael Pujos <pujos.michael@gmail.com>
- updated build to use meson rather than plain Makefiles
- removed fix_maybe-uninitialized_error.patch not needed anymore
- Update to version 1.31.0
  * Improvements
  - Support r_skyalpha
  - Added Support for JPEG and PNG texture format
  - Support demos larger than 2 GiB
  - Many performance optimizations by @andrei-drexler from Ironwail
  - Increased internal limits on the number of models, triangles,
    sounds...etc. for the most demanding mods
  - We can now play Slayers Testaments.
  - Increase chase cam target trace distance for large open maps
  - Add set and seta commands
  - Add 2+3 arg forms of the toggle command
  - Backport angled sprites code from FTEQW
  - Tweak scr_viewsize 130 (hide pause, momentarily show notices)
  - Multithreading performance improvements by @Novum and @temx
  - Library updates
  - Code cleanups
  * Fixes
  - Clear button status on map load to prevent stray fires/jumps
  - Fix Dutch angle VP_PARALLEL_UPRIGHT sprites
  - Fix potential buffer overflow in COM_Parse
  - Fix potential buffer overflow in Mod_LoadAliasFrame
  - Fix potential infinite loop in S_PaintChannels
  - Work around some collision issues by @Macil
  - Give the cvars generated from float+vector autocvars prettier
    default/initial values
  - Fix viewmodel interpolation with >10Hz animations
  - Remove annoying '... is unbound, hit F4 to set' message
  - Fix 'S_FindName: out of sfx_t' errors when switching Mods / maps
* Sun May 19 2024 Carsten Ziepke <kieltux@gmail.com>
- Fix building for openSUSE Leap, use gcc11
* Fri May  5 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add fix_maybe-uninitialized_error.patch
* Sat Mar 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.30.1
  * Add a workaround for AMD driver bug causing corrupted sky and
    a minor Vulkan correctness fix.
* Tue Mar 14 2023 Michael Pujos <pujos.michael@gmail.com>
- removed patch fix-aarch64-build.patch, not needed anymore
- requires vulkan-devel >= 1.2.162
- Update to version 1.30.0
  * Support for remastered models (Needs data from remastered Quake)
  * Support for dynamic lightmap shadows (requires an RT capable GPU)
  * Reworked all option menus
  * Support for modern HUD style
  * Transparency sorting (thanks @temx)
  * Dynamic lights are now computed in world instead of texel space for more consistent light sizes
  * New GPU memory allocator
  * Improved level load times
* Mon Dec 12 2022 Michael Pujos <pujos.michael@gmail.com>
- added patch fix-aarch64-build.patch
- Update to version 1.22.3
  * Mouse support in menus
  * Support for binding weapons in controls menu
- Update to version 1.22.1
  * Fix potential crashes on vid_restart
  * Fix validation error complaining that VK_FORMAT_R32_UINT doesn't
    support linear sampling
- Update to version 1.22.0
  * GPU driven rendering (r_indirect) - much better performance in
    certain scenes (thanks @temx)
  * Windows installer, detects existing Quake installations
  * vkquake.pak is embedded into the executable, external file no longer
    used
  * Configuration is now saved to vkQuake.cfg instead of config.cfg
  * Demo seek support (arrow keys seek 10s, shift+arrows seek 30s,
    seek command bindable to function keys: bind F1 "seek -3")
  * Demo recording is no longer interrupted when loading savegames
  * fastload command loads savegame without reloading level
    (bind F6 "save quick"; bind F9 "fastload quick")
  * Underwater sound filter (snd_waterfx 0 to disable)
  * viewsize 130 for clean screenshots (+/- keys to quickly select)
  * Built-in zooming support (togglezoom, +zoom/-zoom, zoom_fov, zoom_speed)
  * Model .scale support for mods/maps
  * Lightstyles no longer saturate at 2x brightness
  * CPU/GPU optimizations for maps with very large geometry/lightmap
    footprints
  * Fixed pitch-black entities in some Arcane Dimension levels
  * r_speeds works again, r_showbboxes shows edict numbers
  * Various other bug fixes
* Sat Aug 13 2022 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.20.3
  * Fixed multiple parallelism bugs
  * 8-bit mode now has dithering
- Update to version 1.20.2
  * Fixed a crash on startup with re-release Quake data
  * Fixed crash with small stack sized on Unix (e.g. musl libc)
- Update to version 1.20.1
  * Fix a bug that could cause random lockups with 1.20.0
  * Fix screenshot crash
  * Fix corruption if new vkquake.pak is missing or old one is still in place
- Update to version 1.20.0
  * Parallelized renderer for significantly higher performance
  * Parallelized texture mip generation for faster load times
  * SIMD code optimizations
  * "8-bit" color mode emulation
  * Scaling is now less blurry
  * Mods menu
  * Completely replaced memory management (no more -heapsize)
* Mon May 16 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.13.1:
  * GUI scale is now relative to screen height (scr_relativescale 0
    to disable).
  * Crosshair is selectable from menu and added option for dot
    instead of cross.
  * Improved compatibility with latest Quake Steam re-release
    version.
  * Various smaller bug fixes
- Update to version 1.13.0:
  * GPU lightmap update and smooth dynamic light interpolation
  * Various bug fixes
  * Improved compatibility with 2021 Quake re-release
  Known issues:
  * Some entities don't animate smoothly with FTE protocol
    extensions. cl_nopext 1 is a workaround right now.
    Same bug exists in QSS.
* Fri Feb 18 2022 Matthias Mailänder <mailaender@opensuse.org>
- Fix screenshot URL
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.12.2:
  * Improved compatibility with the 2021 Quake re-release
  * Various bug fixes
  * Small performance improvements
  * Improved support for non power of two textures
  * Updated SDL to 2.0.18
- remove 0001-Fix-format-overflow-warning-with-32-bit-gcc.patch: upstream
* Mon Dec  6 2021 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-Fix-format-overflow-warning-with-32-bit-gcc.patch
* Fri Nov 26 2021 Martin Hauke <mardnh@gmx.de>
- Fix source url
* Fri Nov 26 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.12.1
  * Bugfix release
* Thu Nov 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.12.0
  * Support for scriptable particles ported from QuakeSpasm-Spiked
    (e.g. for Arcane Dimensions). If vanilla behavior is wanted
    they can be diabled with r_fteparticles 0
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.11.1
  * Improved compatibility with 2021 Quake re-release
  Known issues:
  * Some entities don't animate smoothly with FTE protocol
  extensions. cl_nopext 1 is a workaround right now. Same bug
  exists in QSS.
* Sat Sep  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.11.0
  * Initial support for Quake 2021 re-release
  * External vis file support
- Update to version 1.10.0
  * Merged protocol extensions from QuakeSpasm-Spiked. This fixes
    non smooth movement on elevators in certain cases.
  * Custom HUD client side QuakeC support for Arcane Dimensions
    (disable with cl_nocsqc 1).
  * SIMD CPU optimizations from Andrei Drexler - especially helpful
    in complex levels like ad_tears.
  * Stencil buffer optimizations for sky rendering reducing
    overdraw.
  * Resolution scaling to 1/2 1/4 or 1/8th resolution.
  * Added support for r_fullbright & r_lightmap.
  * Implemented full r_showtris support.
  * Option in menu to set max frame rate.
  * Higher precision game time and precise frame rate throttling.
  * Fix exclusive full screen alt+tab issues.
  * Bumped default heap size to 384MB.
  Changes from beta1:
  * Fixed potential issue with Intel GPUs and render scale.
  * Renamed "filter" to "textures" in menu to make it more clear
    what the option does.
  * Fixed missing gun icons in HUD.
  Changes from beta2:
  * Fixes ambient sounds.
  * Multiple memory corruption fixes.
  * Fix compatibility with some mods.
- Update to version 1.05.3
  * Fixed dynamic lights not updating properly.
  * Added menu options for particles (GL or software style).
  * Added "exclusive" menu option to fullscreen setting to control
    VK_EXT_full_screen_exclusive.
  * Removed a bunch of rendering cvars that do nothing in vkQuake.
  * Fixed edge case with out of range fog values.
- Strip binary
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.05.2
  * Only use VK_EXT_full_screen_exclusive with NVIDIA drivers as
    people reported problems with other configurations
  * Fall back to non exclusive full screen if swap chain can't be created
  * Fix descriptor set leak
  * Fix rare crash in vertex buffer memory management
  * Fix world dynamic light update lagging one frame behind brushes
* Sat Dec 26 2020 Jacob Tice <jacob.a.tice@gmail.com>
- Update to version 1.05.1
- Drop 0001-Remove-use-of-VK_DYNAMIC_STATE_RANGE_SIZE.patch
* Sun Sep 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix the factory build:
  * 0001-Remove-use-of-VK_DYNAMIC_STATE_RANGE_SIZE.patch
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.04.1. Changes since 1.02.0:
  * Lots of Vulkan fixes
  * Frame rates over 72 Hz don't break physics anymore
  * Default maximum frame rate raised to 200 Hz.
  * Fix crashes with some Intel drivers and anti aliasing
  * Fix crash "out of dynamic vertex buffer space"
    in some very large custom maps
  * Fix gun position being different than in QuakeSpasm
    when status bar alpha is 0
  * Fixed alpha tested alias models
  * Fixed too large dynamic buffer allocations
  * Lightmaps are now dynamically allocated (from QuakeSpasm)
  * Particles are now rendered as quads instead of triangles
    by default (r_quadparticles) like in QuakeSpasm.
  * Fix alpha tested geo not testing depth
  * Fix issue where wrong push constants were being
    set if render size is smaller than window
  * Fixed certain UI elementes being rendered with alpha
    blending instead of alpha testing like in QS
  * Fix issue with Intel GPUs crashing when leaving full screen
  * Updated to latest QuakeSpasm code
  * Fix particle alpha being affected by fog
* Mon Jun 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.02.0
  + Frame rates over 72 Hz don't break physics anymore (from
    QuakeSpasm spiked)
  + Default maximum frame rate raised to 200 Hz.
  + Fix crashes with some Intel drivers and anti aliasing
  + Fix crash "out of dynamic vertex buffer space" in some very
    large custom maps
  + Fix gun position being different than in QuakeSpasm when status
    bar alpha is 0
  + Other minor Vulkan fixes
- Update to version 1.01.0
  + Extremely large textures should now work
  + Fixed alpha blending issue in some maps
    (e.g. xmasjam2018_bloodshot)
  + Partial support for r_showTris (world and particles)
  + Update to latest QuakeSpasm code
* Sun Oct 14 2018 sean@suspend.net
- Update to 1.00.0
  + Peformance optimizations (use function pointer instead of loader)
  + Compute shader water texture update
  + Update to latest QuakeSpasm code
* Tue Jun 27 2017 luke.nukem.jones@gmail.com
- Update to 0.96.2
  + Fix for AMD hang
- Changes from 0.96.1
  + Bump limits for Arcane Dimensions 1.60 (ad_sepulcher)
  + Fix for broken dynamic lights since version 0.92
  + Add fence between command buffer completion and present
    (required by Vulkan spec)
  + Potential optimization for some drivers: Mark command buffers as
    VK_COMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BIT
* Thu Jun 15 2017 boris@steki.net
- update Source url to work as intended
* Tue Jun 13 2017 luke.nukem.jones@gmail.com
- Initial packaging
